# concert bot
## greet
你好
今天天气不错
很高兴认识你
大家好

## thankyou
谢谢
感谢
谢谢你

## goodbye
再见
再会
明天见

## affirm
是的
正确
对
没错

## deny
不对
错
错误
不行
我拒绝

## mood_great
我很好
天气不错
心情不错
心情很好
一切顺利
很好
好

## mood_unhappy
想哭
难受
蓝瘦香菇
郁闷
很不好

## bot_challenge
你是机器人吗
你是傻子吗
你是人类吗

## search_concerts
我想找[place:concert](音乐会)
演唱会

## search_venues
场地在哪儿
场馆在哪儿

## compare_reviews
评价如何
哪个好
我应该选择哪个

